aboutsummaryrefslogtreecommitdiffstats
path: root/modules/notification/base/null.go
diff options
context:
space:
mode:
authorzeripath <art27@cantab.net>2020-04-30 21:24:08 +0100
committerGitHub <noreply@github.com>2020-04-30 21:24:08 +0100
commit4974b7c120102b49548197e58c7a58181ba52170 (patch)
treea7769043d9c541bfd1af688ffa7fa76b75b99223 /modules/notification/base/null.go
parentab69b9b1a60a83cf2b5d6c021da0cb35540df10f (diff)
downloadgitea-4974b7c120102b49548197e58c7a58181ba52170.tar.gz
gitea-4974b7c120102b49548197e58c7a58181ba52170.zip
Fix spelling mistake with Rewiew (#11262)
Signed-off-by: Andrew Thornton <art27@cantab.net>
Diffstat (limited to 'modules/notification/base/null.go')
-rw-r--r--modules/notification/base/null.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/notification/base/null.go b/modules/notification/base/null.go
index 4b5efd80bb..d2fd51d713 100644
--- a/modules/notification/base/null.go
+++ b/modules/notification/base/null.go
@@ -86,8 +86,8 @@ func (*NullNotifier) NotifyIssueChangeContent(doer *models.User, issue *models.I
func (*NullNotifier) NotifyIssueChangeAssignee(doer *models.User, issue *models.Issue, assignee *models.User, removed bool, comment *models.Comment) {
}
-// NotifyPullRewiewRequest places a place holder function
-func (*NullNotifier) NotifyPullRewiewRequest(doer *models.User, issue *models.Issue, reviewer *models.User, isRequest bool, comment *models.Comment) {
+// NotifyPullReviewRequest places a place holder function
+func (*NullNotifier) NotifyPullReviewRequest(doer *models.User, issue *models.Issue, reviewer *models.User, isRequest bool, comment *models.Comment) {
}
// NotifyIssueClearLabels places a place holder function